@@ -1,5 +1,5 @@
-__version__ = "0.4.2"
+__version__ = "0.5.0"
 # flake8: noqa F401
 from screenlogicpy.gateway import ScreenLogicGateway
 from screenlogicpy.const import ScreenLogicError
-from screenlogicpy.discovery import discover
+from screenlogicpy.discovery import async_discover
